@@ -170,7 +170,8 @@ sub do_http {
 		my ($multi_ev, $easy, $url, $opt, $cb) = @_;
 		my $finish = _prepare($easy, $url, $opt);
 		if ($multi_ev) {
-			$multi_ev->($easy, sub { $cb->($finish->(@_)) }, $$opt{timeout} + 10);
+			my $timeout = $$opt{timeout} || 300;
+			$multi_ev->($easy, sub { $cb->($finish->(@_)) }, $timeout);
 		} else {
 			$cb->(_do_http($easy, $url, $opt));
 		}
